package dev.peerat.parser.java.printer;

import dev.peerat.parser.java.JavaElement;
import dev.peerat.parser.java.operation.IfOperation;
import dev.peerat.parser.java.operation.ReturnOperation;
import dev.peerat.parser.java.value.Value;

public class JavaOperationPrinter{
	
	public static class JavaOperationReturnPrinter extends JavaPrinter<ReturnOperation>{

		@Override
		public void print(ReturnOperation element, Writer writer, String buffer, JavaPrintProvider provider)throws Exception {
			writer.write(buffer+"return");
			Value value = element.getValue();
			if(value == null){
				writer.write(";");
				return;
			}
			writer.write(" ");
			provider.getPrinter(value).print(value, writer, "", provider);
			writer.write(";");
		}
		
	}
	
	public static class JavaOperationIfPrinter extends JavaPrinter<IfOperation>{
		
		@Override
		public void print(IfOperation element, Writer writer, String buffer, JavaPrintProvider provider) throws Exception {
			writer.write(buffer+"if(");
			Value condition = element.getCondition();
			provider.getPrinter(condition).print(condition, writer, "", provider);
			writer.write(")");
			int size = element.getElements().size();
			if(size == 0){
				writer.write(";");
				return;
			}
			if(size == 1){
				writer.write(" ");
				JavaElement subElement = element.getElements().get(0);
				provider.getPrinter(subElement).print(subElement, writer, "", provider);
				writer.write(";");
				return;
			}
			writer.write("{\n");
			for(JavaElement subElement : element.getElements()){
				provider.getPrinter(subElement).print(subElement, writer, buffer+"\t", provider);
				writer.write("\n");
			}
			writer.write(buffer+"}\n");
		}
		
	}

}
